# GEOGLOWS
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/geoglows.svg)](https://img.shields.io/conda/vn/conda-forge/geoglows.svg)
[![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/geoglows.svg)](https://anaconda.org/conda-forge/geoglows)
[![PyPI](https://img.shields.io/pypi/v/geoglows)](https://pypi.org/project/geoglows)

[Visit the Conda Forge page](https://github.com/conda-forge/geoglows-feedstock)
```bash
conda install -c conda-forge geoglows
```

Also available on pypi

[Visit the PyPi page](https://pypi.org/project/geoglows)

```bash
pip install geoglows
```

Tools to access and process data coming from the GEOGLOWS initiative.

https://geoglows.readthedocs.io
